autoDispose property
Whether to automatically dispose the signal (defaults to SolidartConfig.autoDispose).
This happens automatically when there are no longer subscribers. If you set it to false, you should remember to dispose the signal manually
Implementation
final bool autoDispose;