ReactiveSystem class
Constructors
Properties
- activeSub → ReactiveNode?
-
no setter
- batchDepth → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
endBatch(
) → void -
flush(
) → void -
getComputedValue<
T> (_AlienComputed< T> computed) → T -
getSignalValue<
T> (_AlienSignal< T> signal) → Option<T> -
link(
ReactiveNode dep, ReactiveNode sub) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
propagate(
Link link) → void -
runEffect(
ReactiveNode effect) → void -
setCurrentSub(
ReactiveNode? sub) → ReactiveNode? -
setSignalValue<
T> (_AlienSignal< T> signal, Option<T> value) → void -
startBatch(
) → void -
stopEffect(
ReactiveNode effect) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited